@@ -1,3 +1,3 @@
 from mope.client import Mope
 
-__all__ = ['Mope']
+__all__ = ["Mope"]
